summaryrefslogtreecommitdiffstats
path: root/lib/kross/api/eventaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/api/eventaction.h')
-rw-r--r--lib/kross/api/eventaction.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/kross/api/eventaction.h b/lib/kross/api/eventaction.h
index e20656df..602a697f 100644
--- a/lib/kross/api/eventaction.h
+++ b/lib/kross/api/eventaction.h
@@ -33,7 +33,7 @@ namespace Kross { namespace Api {
class ScriptContainer;
/**
* The EventAction class is used to wrap KAction instances
* into the Kross object hierachy and provide access to
* them.
*/
@@ -50,7 +50,7 @@ namespace Kross { namespace Api {
/**
* Constructor.
*/
- EventAction(const TQString& name, KAction* action);
+ EventAction(const TQString& name, TDEAction* action);
/**
* Destructor.
@@ -64,7 +64,7 @@ namespace Kross { namespace Api {
//virtual Object::Ptr call(const TQString& name, TDESharedPtr<List> arguments);
private:
- KAction* m_action;
+ TDEAction* m_action;
/// \return the text associated with this action.
Kross::Api::Object::Ptr getText(Kross::Api::List::Ptr);
@@ -33,7 +33,7 @@ namespace Kross { namespace Api {
class ScriptContainer;
/**
- * The EventAction class is used to wrap KAction instances
+ * The EventAction class is used to wrap TDEAction instances
* into the Kross object hierachy and provide access to
* them.